# cqterrain
Helper Libary to Generate 3d models of greebles, buildings, and terrain using [CadQuery](https://cadquery.readthedocs.io/en/latest/intro.html).

![](https://raw.githubusercontent.com/medicationforall/cqterrain/refs/heads/main/documentation/image/book/cover.png)

## Links
* [README.md](https://github.com/medicationforall/cqterrain)
* [Documentation](https://github.com/medicationforall/cqterrain/blob/main/documentation/documentation.md)
* [Changelog](https://github.com/medicationforall/cqterrain/blob/main/changes.md)

## Dependencies
* [CadQuery 2.x](https://github.com/CadQuery/cadquery)
* [cadqueryhelper](https://github.com/medicationforall/cadqueryhelper)

## Example Projects
* [Jersey Barrier Set](https://miniforall.com/jerseybarriers)
* [Pipe Terrain Set](https://miniforall.com/pipeterrain)
* [Shieldwall Terrain Set](https://miniforall.com/shieldwall)
* [Walkway Terrain Set](https://miniforall.com/walkways)
